@@ -26,6 +26,35 @@ class MariadbClient(AbstractClient):
     _service = 'mariadb'
 
 
+    def ActivateHourDBInstance(self, request):
+        """解隔离后付费实例
+
+        :param request: Request instance for ActivateHourDBInstance.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.ActivateHourDBInstanceRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.ActivateHourDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ActivateHourDBInstance", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ActivateHourDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def AssociateSecurityGroups(self, request):
         """本接口 (AssociateSecurityGroups) 用于安全组批量绑定云资源。
 
@@ -36,7 +65,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AssociateSecurityGroups", params)
+            headers = request.headers
+            body = self.call("AssociateSecurityGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AssociateSecurityGroupsResponse()
@@ -64,7 +94,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CancelDcnJob", params)
+            headers = request.headers
+            body = self.call("CancelDcnJob", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CancelDcnJobResponse()
@@ -92,7 +123,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CloneAccount", params)
+            headers = request.headers
+            body = self.call("CloneAccount", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CloneAccountResponse()
@@ -120,7 +152,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CloseDBExtranetAccess", params)
+            headers = request.headers
+            body = self.call("CloseDBExtranetAccess", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CloseDBExtranetAccessResponse()
@@ -149,7 +182,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CopyAccountPrivileges", params)
+            headers = request.headers
+            body = self.call("CopyAccountPrivileges", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CopyAccountPrivilegesResponse()
@@ -177,7 +211,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAccount", params)
+            headers = request.headers
+            body = self.call("CreateAccount", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAccountResponse()
@@ -205,7 +240,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBInstanceResponse()
@@ -233,7 +269,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDedicatedClusterDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateDedicatedClusterDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDedicatedClusterDBInstanceResponse()
@@ -261,7 +298,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateHourDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateHourDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateHourDBInstanceResponse()
@@ -289,7 +327,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTmpInstances", params)
+            headers = request.headers
+            body = self.call("CreateTmpInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTmpInstancesResponse()
@@ -317,7 +356,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAccount", params)
+            headers = request.headers
+            body = self.call("DeleteAccount", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAccountResponse()
@@ -346,7 +386,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccountPrivileges", params)
+            headers = request.headers
+            body = self.call("DescribeAccountPrivileges", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccountPrivilegesResponse()
@@ -374,7 +415,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccounts", params)
+            headers = request.headers
+            body = self.call("DescribeAccounts", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccountsResponse()
@@ -402,7 +444,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupTime", params)
+            headers = request.headers
+            body = self.call("DescribeBackupTime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupTimeResponse()
@@ -430,7 +473,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstanceSpecs", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstanceSpecs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstanceSpecsResponse()
@@ -459,7 +503,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstances", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstancesResponse()
@@ -487,7 +532,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBLogFiles", params)
+            headers = request.headers
+            body = self.call("DescribeDBLogFiles", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBLogFilesResponse()
@@ -515,7 +561,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBParameters", params)
+            headers = request.headers
+            body = self.call("DescribeDBParameters", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBParametersResponse()
@@ -543,7 +590,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBPerformance", params)
+            headers = request.headers
+            body = self.call("DescribeDBPerformance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBPerformanceResponse()
@@ -571,7 +619,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBPerformanceDetails", params)
+            headers = request.headers
+            body = self.call("DescribeDBPerformanceDetails", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBPerformanceDetailsResponse()
@@ -599,7 +648,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBResourceUsage", params)
+            headers = request.headers
+            body = self.call("DescribeDBResourceUsage", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBResourceUsageResponse()
@@ -627,7 +677,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBResourceUsageDetails", params)
+            headers = request.headers
+            body = self.call("DescribeDBResourceUsageDetails", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBResourceUsageDetailsResponse()
@@ -645,34 +696,6 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeDBSecurityGroups(self, request):
-        """本接口（DescribeDBSecurityGroups）用于查询实例安全组信息
-
-        :param request: Request instance for DescribeDBSecurityGroups.
-        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeDBSecurityGroupsRequest`
-        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeDBSecurityGroupsResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeDBSecurityGroups", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeDBSecurityGroupsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeDBSlowLogs(self, request):
         """本接口(DescribeDBSlowLogs)用于查询慢查询日志列表。
 
@@ -683,7 +706,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBSlowLogs", params)
+            headers = request.headers
+            body = self.call("DescribeDBSlowLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBSlowLogsResponse()
@@ -701,6 +725,64 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDatabaseObjects(self, request):
+        """本接口（DescribeDatabaseObjects）用于查询云数据库实例的数据库中的对象列表，包含表、存储过程、视图和函数。
+
+        :param request: Request instance for DescribeDatabaseObjects.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeDatabaseObjectsRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeDatabaseObjectsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDatabaseObjects", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDatabaseObjectsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDatabaseTable(self, request):
+        """本接口（DescribeDatabaseTable）用于查询云数据库实例的表信息。
+
+        :param request: Request instance for DescribeDatabaseTable.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeDatabaseTableRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeDatabaseTableResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDatabaseTable", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDatabaseTableResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDatabases(self, request):
         """本接口（DescribeDatabases）用于查询云数据库实例的数据库列表。
 
@@ -711,7 +793,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDatabases", params)
+            headers = request.headers
+            body = self.call("DescribeDatabases", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDatabasesResponse()
@@ -739,7 +822,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDcnDetail", params)
+            headers = request.headers
+            body = self.call("DescribeDcnDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDcnDetailResponse()
@@ -767,7 +851,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileDownloadUrl", params)
+            headers = request.headers
+            body = self.call("DescribeFileDownloadUrl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFileDownloadUrlResponse()
@@ -795,7 +880,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFlow", params)
+            headers = request.headers
+            body = self.call("DescribeFlow", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFlowResponse()
@@ -823,7 +909,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceNodeInfo", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceNodeInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceNodeInfoResponse()
@@ -851,7 +938,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeLogFileRetentionPeriod", params)
+            headers = request.headers
+            body = self.call("DescribeLogFileRetentionPeriod", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeLogFileRetentionPeriodResponse()
@@ -869,34 +957,6 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeOrders(self, request):
-        """本接口（DescribeOrders）用于查询云数据库订单信息。传入订单ID来查询订单关联的云数据库实例，和对应的任务流程ID。
-
-        :param request: Request instance for DescribeOrders.
-        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeOrdersRequest`
-        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeOrdersResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeOrders", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeOrdersResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribePrice(self, request):
         """本接口（DescribePrice）用于在购买实例前，查询实例的价格。
 
@@ -907,7 +967,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePrice", params)
+            headers = request.headers
+            body = self.call("DescribePrice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePriceResponse()
@@ -935,7 +996,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeProjectSecurityGroups", params)
+            headers = request.headers
+            body = self.call("DescribeProjectSecurityGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeProjectSecurityGroupsResponse()
@@ -963,7 +1025,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRenewalPrice", params)
+            headers = request.headers
+            body = self.call("DescribeRenewalPrice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRenewalPriceResponse()
@@ -991,7 +1054,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSaleInfo", params)
+            headers = request.headers
+            body = self.call("DescribeSaleInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSaleInfoResponse()
@@ -1019,7 +1083,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSqlLogs", params)
+            headers = request.headers
+            body = self.call("DescribeSqlLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSqlLogsResponse()
@@ -1047,7 +1112,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUpgradePrice", params)
+            headers = request.headers
+            body = self.call("DescribeUpgradePrice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUpgradePriceResponse()
@@ -1075,7 +1141,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DestroyHourDBInstance", params)
+            headers = request.headers
+            body = self.call("DestroyHourDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DestroyHourDBInstanceResponse()
@@ -1103,7 +1170,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DisassociateSecurityGroups", params)
+            headers = request.headers
+            body = self.call("DisassociateSecurityGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DisassociateSecurityGroupsResponse()
@@ -1131,7 +1199,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("FlushBinlog", params)
+            headers = request.headers
+            body = self.call("FlushBinlog", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.FlushBinlogResponse()
@@ -1160,7 +1229,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GrantAccountPrivileges", params)
+            headers = request.headers
+            body = self.call("GrantAccountPrivileges", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GrantAccountPrivilegesResponse()
@@ -1188,7 +1258,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InitDBInstances", params)
+            headers = request.headers
+            body = self.call("InitDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InitDBInstancesResponse()
@@ -1206,6 +1277,35 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def IsolateHourDBInstance(self, request):
+        """隔离后付费实例
+
+        :param request: Request instance for IsolateHourDBInstance.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.IsolateHourDBInstanceRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.IsolateHourDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("IsolateHourDBInstance", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.IsolateHourDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def KillSession(self, request):
         """本接口（KillSession）用于杀死指定会话。
 
@@ -1216,7 +1316,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("KillSession", params)
+            headers = request.headers
+            body = self.call("KillSession", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.KillSessionResponse()
@@ -1245,7 +1346,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccountDescription", params)
+            headers = request.headers
+            body = self.call("ModifyAccountDescription", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAccountDescriptionResponse()
@@ -1278,7 +1380,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccountPrivileges", params)
+            headers = request.headers
+            body = self.call("ModifyAccountPrivileges", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAccountPrivilegesResponse()
@@ -1306,7 +1409,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyBackupTime", params)
+            headers = request.headers
+            body = self.call("ModifyBackupTime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyBackupTimeResponse()
@@ -1334,7 +1438,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceName", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceName", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceNameResponse()
@@ -1362,7 +1467,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceSecurityGroups", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceSecurityGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceSecurityGroupsResponse()
@@ -1390,7 +1496,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstancesProject", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstancesProject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstancesProjectResponse()
@@ -1418,7 +1525,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBParameters", params)
+            headers = request.headers
+            body = self.call("ModifyDBParameters", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBParametersResponse()
@@ -1446,7 +1554,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBSyncMode", params)
+            headers = request.headers
+            body = self.call("ModifyDBSyncMode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBSyncModeResponse()
@@ -1474,7 +1583,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyLogFileRetentionPeriod", params)
+            headers = request.headers
+            body = self.call("ModifyLogFileRetentionPeriod", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyLogFileRetentionPeriodResponse()
@@ -1507,7 +1617,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyRealServerAccessStrategy", params)
+            headers = request.headers
+            body = self.call("ModifyRealServerAccessStrategy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyRealServerAccessStrategyResponse()
@@ -1535,7 +1646,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifySyncTaskAttribute", params)
+            headers = request.headers
+            body = self.call("ModifySyncTaskAttribute", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifySyncTaskAttributeResponse()
@@ -1563,7 +1675,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("OpenDBExtranetAccess", params)
+            headers = request.headers
+            body = self.call("OpenDBExtranetAccess", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.OpenDBExtranetAccessResponse()
@@ -1591,7 +1704,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenewDBInstance", params)
+            headers = request.headers
+            body = self.call("RenewDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenewDBInstanceResponse()
@@ -1620,7 +1734,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResetAccountPassword", params)
+            headers = request.headers
+            body = self.call("ResetAccountPassword", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResetAccountPasswordResponse()
@@ -1648,7 +1763,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartDBInstances", params)
+            headers = request.headers
+            body = self.call("RestartDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartDBInstancesResponse()
@@ -1666,6 +1782,35 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SwitchDBInstanceHA(self, request):
+        """本接口（SwitchDBInstanceHA）用于发起实例主备切换。
+
+        :param request: Request instance for SwitchDBInstanceHA.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.SwitchDBInstanceHARequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.SwitchDBInstanceHAResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SwitchDBInstanceHA", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SwitchDBInstanceHAResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpgradeDBInstance(self, request):
         """本接口(UpgradeDBInstance)用于扩容云数据库实例。本接口完成下单和支付两个动作，如果发生支付失败的错误，调用用户账户相关接口中的支付订单接口（PayDeals）重新支付即可。
 
@@ -1676,7 +1821,8 @@ class MariadbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpgradeDBInstance", params)
+            headers = request.headers
+            body = self.call("UpgradeDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpgradeDBInstanceResponse()
